#include "estimator.h"

namespace lidar_tracker {

void Estimator::Init(double x, double y, double vx, double vy,
                     double timestamp) {
  kf_.Init(x, y, vx, vy);
  kf_timestamp_ = timestamp;
}

std::pair<Eigen::Vector4d, Eigen::Matrix4d> Estimator::ComputePrediction(
    double timestamp) const {
  const double dt = timestamp - kf_timestamp_;
  // TODO(somebody) check dt > 0
  return kf_.ComputePrediction(dt);
}

void Estimator::PredictAndUpdate(const ObservationProto& observation) {
  const double dt = observation.timestamp() - kf_timestamp_;
  kf_.Predict(dt);
  const auto& lidar_observation = observation.lidar_observation();
  kf_.Update(lidar_observation.center_x(), lidar_observation.center_y());
  kf_timestamp_ = observation.timestamp();
}

double Estimator::x() const { return kf_.x(); }
double Estimator::y() const { return kf_.y(); }
double Estimator::vx() const { return kf_.vx(); }
double Estimator::vy() const { return kf_.vy(); }
Eigen::Vector2d Estimator::pos() { return kf_.pos(); }
Eigen::Vector2d Estimator::vel() { return kf_.vel(); }

}  // namespace lidar_tracker
